/**
 *  \file       CTheoreticalModel.h
 *  \author     Joe Author (jauthor@institute.edu)
 *  \date       Apr 17, 2010
 *  \brief      Definition file for CTheoreticalModel class
 */

#ifndef CTHEORETICALMODEL_H_
#define CTHEORETICALMODEL_H_


/**
 *  \brief  Theoretical Model derived in section \f$\ref{paper-sec:Model}\f$,
 *          page \f$\pageref{paper-sec:Model}\f$
 *
 *  This is a detailed description of the model
 */
class CTheoreticalModel
{
    private:
        double    m_alpha;    ///< [parameter] defined in equation \f$\ref{paper-eqn:alphaDef}\f$
        double    m_beta;     ///< [parameter] defined in equation \f$\ref{paper-eqn:betaDef}\f$

    public:
        /**
         *  \brief      Construct a new model using the given parameters
         *  \param[in]  alpha   [parameter] defined in equation
         *                      \f$\ref{paper-eqn:alphaDef}\f$
         *  \param[in]  beta    [parameter] defined in equation
         *                      \f$\ref{paper-eqn:betaDef}\f$
         */
        CTheoreticalModel( double alpha, double beta );


        /**
         *  \brief      calculates [some property] by implementing algorithm
         *              \f$\ref{paper-alg:SomeAlgorithm}\f$ on page
         *              \f$\pageref{paper-alg:SomeAlgorithm}\f$
         *  \return     [some property]
         */
        double algorithmA();


        /**
         *  \brief      updates the model by [some parameter] according to the
         *              dynamics of equation \f$\ref{paper-eqn:SomeEquation}\f$
         *              on page \f$\pageref{paper-eqn:SomeEquation}\f$
         *  \param[in]  gamma   [parameter] defined in equation
         *                      \f$\ref{paper-eqn:gammaDef}\f$
         */
        void equationB( double gamma );


        /**
         *  \brief      tests [some parameter] against the model; implements
         *              condition \f$\ref{paper-eqn:SomeCondition}\f$
         *  \param[in]  theta   [some parameter] defined by equation
         *                      \f$\ref{paper-eqn:thetaDef}\f$
         */
        bool testC( double theta );
};

#endif /* CTHEORETICALMODEL_H_ */
